| Title: | Resizable Split Layout Module for 'shiny' |
|---|---|
| Description: | A 'shiny' module to facilitate page layouts with resizable panes for page content based on 'split.js' 'JavaScript' library (<https://split.js.org>). |
| Authors: | Michael Schaffer [aut, cre] (ORCID: <https://orcid.org/0000-0003-1381-0275>) |
| Maintainer: | Michael Schaffer <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-06-08 08:31:41 UTC |
| Source: | https://github.com/cran/resizableSplitLayout |
This function launches a simple Shiny application demonstrating how to use
the resizableSplitLayout module.
resizableSplitDemo()resizableSplitDemo()
No return value, called for side effects (launches a Shiny app)
# Run this function to see the module in action if (interactive()) { resizableSplitDemo() }# Run this function to see the module in action if (interactive()) { resizableSplitDemo() }
resizableSplitUI
resizableSplitUI( id, sidebarpane, maincontenttop, maincontentbottom, sidebar.percentage = 15, maincontenttop.percentage = 85, return.only.taglist = FALSE )resizableSplitUI( id, sidebarpane, maincontenttop, maincontentbottom, sidebar.percentage = 15, maincontenttop.percentage = 85, return.only.taglist = FALSE )
id |
Module identifier |
sidebarpane |
Content for page sidebar |
maincontenttop |
Content for page main top pane |
maincontentbottom |
Content for page main bottom pane |
sidebar.percentage |
Width for sidebar as percentage |
maincontenttop.percentage |
Height for page main top pane as percentage |
return.only.taglist |
logical to return taglist instead of a bootstrapPage |
A Shiny UI object. If return.only.taglist = TRUE, returns a
shiny.tag.list object containing the resizable split layout elements.
If return.only.taglist = FALSE (default), returns a Shiny bootstrap
page (from shiny::bootstrapPage) containing the resizable layout.
if (interactive()) { ui <- resizableSplitUI("splitModule", sidebarpane = shiny::div("This is the sidebar"), maincontenttop = shiny::div("This is the maincontenttop"), maincontentbottom = shiny::div("This is the maincontentbottom") ) server <- function(input, output, session) { } shinyApp(ui, server) }if (interactive()) { ui <- resizableSplitUI("splitModule", sidebarpane = shiny::div("This is the sidebar"), maincontenttop = shiny::div("This is the maincontenttop"), maincontentbottom = shiny::div("This is the maincontentbottom") ) server <- function(input, output, session) { } shinyApp(ui, server) }